@@ -106,7 +106,7 @@ class Transformer(nn.Module):
             post_softmax_attns.append(post_softmax_attn)
 
             x = x + attn_out
-            x = ff(x)
+            x = ff(x) + x
 
         if not return_attn:
             return x
